Smart serialization and deserialization for (almost) any python object

# Install

To get the bare minimum without any dependencies. This will give you support for JSON, Gzip, Pickle and plain text
files.

```shell
pip install deli
```

To install the complete set of formats use

```shell
pip install deli[all]
```
